@@ -4,12 +4,8 @@
 #include <R_ext/RS.h>
 
 void F77_SUB(inv)(int *n, double *A, double *invA, int *info);
-void F77_SUB(inv2)(int *n, double *A, double *invA, int *info);
-void F77_SUB(inv3)(int *n, double *A, double *invA, int *info);
 
 void F77_SUB(solve)(double *A, double *b, int *n, int *info);
-void F77_SUB(solve2)(double *A, double *b, int *n, int *info);
-void F77_SUB(solve3)(double *A, double *b, int *n, int *info);
 
 void F77_SUB(identitylink)(double *x, int *n, double *mu);
 void F77_SUB(identitylinkinv)(double *x, int *n, double *eta);
@@ -45,19 +41,19 @@ F77_SUB(hessian)(double *theta, double *se, double *lambda, double *xtx,
 
 void
 F77_SUB(islasso2)(double *X, double *y, int *n, int *p, double *theta, double *se,
-                 double *cov, double *lambda, double *alpha, double *pi, int *estpi,
-                 double *h, int *itmax, double *tol, double *sigma2, int *trace,
-                 int *adaptive, double *offset, int *conv, int *stand, int *intercept,
-                 double *eta, double *mu, double *res, double *dev, double *weights,
-                 double *hi, double *edf, double *grad2);
-
-void
-F77_SUB(islasso_glm)(double *X, double *y, int *n, int *p, double *theta, double *se,
                   double *cov, double *lambda, double *alpha, double *pi, int *estpi,
                   double *h, int *itmax, double *tol, double *sigma2, int *trace,
                   int *adaptive, double *offset, int *conv, int *stand, int *intercept,
-                  double *eta, double *mu, double *dev, double *weights, double *hi,
-                  double *edf, int *fam, int *link, double *grad2);
+                  double *eta, double *mu, double *res, double *dev, double *weights,
+                  double *hi, double *edf, double *grad2);
+
+void
+F77_SUB(islasso_glm)(double *X, double *y, int *n, int *p, double *theta, double *se,
+                     double *cov, double *lambda, double *alpha, double *pi, int *estpi,
+                     double *h, int *itmax, double *tol, double *sigma2, int *trace,
+                     int *adaptive, double *offset, int *conv, int *stand, int *intercept,
+                     double *eta, double *mu, double *dev, double *weights, double *hi,
+                     double *edf, int *fam, int *link, double *grad2);
 
 void
 F77_SUB(family)(int *fam, int *link, int *func, double *x, int *n, double *y);
@@ -87,8 +83,12 @@ void
 F77_SUB(setdiff)(int *p, int *iprofile, int *ind_noprofile);
 
 void
-F77_SUB(armijo)(double *beta, double *dir, double *dtg, double *f0,
+F77_SUB(armijo)(double *beta, double *se, double *dir, double *f0,
                 double *alpha, double *h, double *x,
-                double *y, double *w, double *offset, int *n, int *p,
-                double *lambda, double *eta, double *res, double *eps);
+                double *y, double *offset, int *n, int *p,
+                double *lambda, double *eta, double *res, double *pi, double *xtw);
+void
+F77_SUB(armijo2)(double *beta, double *se, double *cov, double *cov1, double *s2,
+                double *f0, double *alpha, double *h, int *n, int *p,
+                double *lambda, double *res, double *pi, double *xtw);
 
